
# Make sure you have upgraded version of pip

Windows
``
py -m pip install --upgrade pip
``
Linux/MAC OS
``
python3 -m pip install --upgrade pip
``

``
Hello this is a linter for LaTex document types. \n
For usage: TeXlinter <"document-name"> \n
If you have your own rules: \n
TeXlinter <"document-name"> --rules="Your own rules
``